# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that represents the Indexer process.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from dbus.service import Object, method, BusName, signal

indexer_dbus_service = "org.sourceforge.striimStreamer"
indexer_dbus_path = "/org/sourceforge/striimStreamer"

class DBusService(Object):
	"""
	This class is a D-Bus service for striim word completion indexer.
	"""

	def __init__(self, streamer):
		"""
		Initialize the D-Bus service.

		@param self: Reference to the DBusService instance.
		@type self: A DBusService object.

		@param indexer: Reference to word completion indexer.
		@type indexer: An CompletionIndexer object.
		"""
		from Striim.Global import session_bus
		bus_name = BusName(indexer_dbus_service, bus=session_bus)
		Object.__init__(self, bus_name, indexer_dbus_path)
		self.__streamer = streamer

	@method(indexer_dbus_service)
	def toggle_play(self):
		"""
		Index text for automatic word completion.

		@param self: Reference to the DBusService instance.
		@type self: A DBusService object.

		@return: A dictionary of words ranked by occurrence.
		@rtype: A Dict object.
		"""
		return self.__streamer.toggle_play()
	
	@method(indexer_dbus_service)	
	def play_new_station(self):
		return self.__streamer.play_new_station()

	@signal(indexer_dbus_service)
	def ready(self):
		return

	@signal(indexer_dbus_service)
	def stopped(self):
		return
		
	@signal(indexer_dbus_service)
	def busy(self):
		return

	@signal(indexer_dbus_service)
	def playlist_error(self):
		return

	@signal(indexer_dbus_service)
	def stream_update(self, metadata_dictionary):
		return

	@signal(indexer_dbus_service)
	def stream_error(self, error):
		return

	@signal(indexer_dbus_service)
	def stream_message(self, message):
		return
